@@ -18,12 +18,18 @@ import fondos
 import habilidades
 import eventos
 import sonidos
+#import musica
 import colores
 import atajos
 import escenas
 import interfaz
-import aplicacion
-import ejemplos
+
+try:
+    import aplicacion
+    import ejemplos
+except ImportError:
+    print "ERROR: no está disponible PyQt4"
+
 
 __doc__ = """
 Módulo pilas
