@@ -2,7 +2,7 @@ import pilas
 
 pilas.iniciar()
 pilas.fondos.Pasto()
-pilas.avisar('Use la tecla "q" para salir.')
+pilas.avisar('Use Alt+q para salir.')
 
 actor = pilas.actores.Actor("data/logo.png")
 
