@@ -11,6 +11,7 @@ import sys
 import copy
 from PyQt4 import QtGui, QtCore
 from PyQt4.QtGui import QWidget
+from PyQt4.phonon import Phonon
 
 try:
     from PyQt4 import QtOpenGL
@@ -422,19 +423,52 @@ class Actor(BaseActor):
                 self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
-class Sonido:
+class _deprecated__Sonido:
 
     def __init__(self, ruta):
         import pygame
         pygame.mixer.init()
-        pygame.mixer.init()
         self.sonido = pygame.mixer.Sound(ruta)
 
     def reproducir(self):
-        # TODO: quitar esta nota...
-        # print "Usando pygame para reproducir sonido"
         self.sonido.play()
-        
+
+class Sonido:
+
+    def __init__(self, media, ruta):
+        self.media = media
+        self.ruta = ruta
+
+        #if self.source.type() != -1:              # -1 stands for invalid file
+        #    self.media.setCurrentSource(self.source)
+        #    #app.connect(media, SIGNAL("finished()"), app, SLOT("quit()"))
+        #else:
+        #    print "error !!!"
+        self.source = Phonon.MediaSource(ruta)
+        self.sonido = Phonon.createPlayer(Phonon.GameCategory, self.source)
+        print "Creando sonido para", ruta
+
+    def reproducir(self):
+        #self.source = Phonon.MediaSource(self.ruta)
+        #self.media.setCurrentSource(self.source)
+        #self.media.play()
+        #self.sonido.setCurrentSource(self.source)
+        self.sonido.seek(0)
+        self.sonido.play()
+
+class Musica:
+
+    def __init__(self, ruta):
+        import pygame
+        pygame.mixer.init()
+        pygame.mixer.music.load(ruta)
+
+    def reproducir(self, repetir=False):
+        import pygame
+        if repetir:
+            pygame.mixer.music.play(-1)
+        else:
+            pygame.mixer.music.play(0)
 
 class Base(motor.Motor):
     
@@ -449,6 +483,10 @@ class Base(motor.Motor):
         self.mouse_y = 0
         self.camara_x = 0
         self.camara_y = 0
+    
+        self.media = Phonon.MediaObject()
+        self.audio = Phonon.AudioOutput(Phonon.MusicCategory)
+        self.path = Phonon.createPath(self.media, self.audio)
 
     def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa):
         self.ancho = ancho
@@ -462,7 +500,7 @@ class Base(motor.Motor):
         self.mostrar_ventana(pantalla_completa)
 
         # Activa la invocacion al evento timerEvent.
-        self.startTimer(1000/60.0)
+        self.startTimer(1000/100.0)
 
     def mostrar_ventana(self, pantalla_completa):
         if pantalla_completa:
@@ -522,7 +560,10 @@ class Base(motor.Motor):
         return (self.camara_x, self.camara_y)
 
     def cargar_sonido(self, ruta):
-        return Sonido(ruta)
+        return Sonido(self.media, ruta)
+
+    def cargar_musica(self, ruta):
+        return Musica(ruta)
 
     def cargar_imagen(self, ruta):
         return Imagen(ruta)
@@ -607,6 +648,11 @@ class Base(motor.Motor):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
         dx, dy = x - self.mouse_x, y - self.mouse_y
+        
+        izquierda, derecha, arriba, abajo = utils.obtener_bordes()
+        x = max(min(derecha, x), izquierda)
+        y = max(min(arriba, y), abajo)
+
         eventos.mueve_mouse.send("Qt::mouseMoveEvent", x=x, y=y, dx=dx, dy=dy)
         self.mouse_x = x
         self.mouse_y = y
@@ -719,7 +765,7 @@ class Base(motor.Motor):
 class Widget(Base, QWidget):
 
     def __init__(self, app):
-        self.nombre = 'qt'
+        self.nombre = 'qt (cuidado: sin acelerar)'
         self.app = app
         QWidget.__init__(self)
         Base.__init__(self)
@@ -747,7 +793,7 @@ class WidgetSugar(Widget):
 
     def __init__(self):
         Widget.__init__(self, None)
-        self.nombre = 'qtsugar'
+        self.nombre = 'qtsugar (cuidado: sin acelerar)'
 
     def ejecutar_bucle_principal(self, mundo, ignorar_errores):
         pass
@@ -781,6 +827,7 @@ class Motor(object):
     def __init__(self, usar_motor):
         if usar_motor == 'qtgl':
             app = QtGui.QApplication([])
+            app.setApplicationName("pilas")
 
             if QGLWidget == object:
                 self.widget = Widget(app)
